-- =============================================
-- SaveToDB Framework for SQLite
-- Version 7.19, March 12, 2018
--
-- Copyright 2017-2018 Gartle Technology Corporation
-- =============================================

CREATE TABLE [QueryList] (
    [ID] INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [TABLE_TYPE] [nvarchar](128) NOT NULL,
    [TABLE_CODE] [ntext],
    [INSERT_PROCEDURE] [ntext],
    [UPDATE_PROCEDURE] [ntext],
    [DELETE_PROCEDURE] [ntext],
    [PROCEDURE_TYPE] [nvarchar](128)
);

CREATE UNIQUE INDEX [QueryList_TableName]
    ON [QueryList] (
    [TABLE_NAME]
);

CREATE VIEW viewQueryList
AS
SELECT
    NULL AS TABLE_SCHEMA
    , t.name AS TABLE_NAME
    , t.type AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    sqlite_master t
WHERE
    t.type IN ('table', 'view')
    AND t.name NOT IN ('sqlite_master', 'sqlite_sequence', 
        'ColumnTranslation', 'ObjectTranslation', 'EventHandlers', 'ParameterValues', 'TableFormats', 'QueryList',
        'viewColumnTranslation', 'viewObjectTranslation', 'viewEventHandlers', 'viewParameterValues', 'viewTableFormats', 'viewQueryList')
UNION
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , t.TABLE_CODE
    , t.INSERT_PROCEDURE
    , t.UPDATE_PROCEDURE
    , t.DELETE_PROCEDURE
    , t.PROCEDURE_TYPE
FROM
    QueryList t
;
    
-- print QueryList has been created

CREATE TABLE [EventHandlers] (
    [ID] INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [COLUMN_NAME] [nvarchar](128),
    [EVENT_NAME] [nvarchar](50) NOT NULL,
    [HANDLER_SCHEMA] [nvarchar](128),
    [HANDLER_NAME] [nvarchar](128),
    [HANDLER_TYPE] [nvarchar](60),
    [HANDLER_CODE] [ntext],
    [TARGET_WORKSHEET] [nvarchar](255),
    [MENU_ORDER] integer,
    [EDIT_PARAMETERS] [bit]
);

CREATE UNIQUE INDEX [EventHandlers_TableName_ColumnName_EventName_HandlerName]
    ON [EventHandlers] (
    [TABLE_NAME], 
    [COLUMN_NAME], 
    [EVENT_NAME], 
    [HANDLER_NAME]
);

-- print EventHandlers has been created

CREATE TABLE [ParameterValues] (
    [ID] INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [PARAMETER_NAME] [nvarchar](128) NOT NULL,
    [SELECT_SCHEMA] [nvarchar](128),
    [SELECT_NAME] [nvarchar](128) NOT NULL,
    [SELECT_TYPE] [nvarchar](128),
    [SELECT_CODE] [ntext]
);

CREATE UNIQUE INDEX [ParameterValues_SpecificName_ParameterName]
    ON [ParameterValues] (
    [TABLE_NAME],
    [PARAMETER_NAME]
);

-- print ParameterValues has been created

CREATE TABLE [ObjectTranslation] (
    [ID] INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [LANGUAGE_NAME] [nchar](2) NOT NULL,
    [TRANSLATED_NAME] [nvarchar](128),
    [TRANSLATED_DESC] [nvarchar](255),
    [TRANSLATED_COMMENT] [nvarchar](4000)
);

CREATE UNIQUE INDEX [IX_ObjectTranslation_TableName_LanguageName]
    ON [ObjectTranslation] (
    [TABLE_NAME],
    [LANGUAGE_NAME]
);

-- print ObjectTranslation has been created

CREATE TABLE [ColumnTranslation] (
    [ID] INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128),
    [COLUMN_NAME] [nvarchar](128) NOT NULL,
    [LANGUAGE_NAME] [nchar](2) NOT NULL,
    [TRANSLATED_NAME] [nvarchar](128),
    [TRANSLATED_DESC] [nvarchar](1024)
);

CREATE UNIQUE INDEX [ColumnTranslation_TableName_ColumnName_Language]
    ON [ColumnTranslation] (
    [TABLE_NAME],
    [COLUMN_NAME],
    [LANGUAGE_NAME]
);

-- print ColumnTranslation has been created

CREATE TABLE [TableFormats] (
    [ID] INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
    [TABLE_SCHEMA] [nvarchar](128),
    [TABLE_NAME] [nvarchar](128) NOT NULL,
    [TABLE_EXCEL_FORMAT_XML] [ntext]
);

CREATE UNIQUE INDEX [TableFormats_TableName]
    ON [TableFormats] (
    [TABLE_NAME]
);

-- print TableFormats has been created

INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, 'ColumnTranslation',NULL, 'Actions',NULL, 'Online Help', 'HTTP', 'http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, 'ObjectTranslation',NULL, 'Actions',NULL, 'Online Help', 'HTTP', 'http://www.savetodb.com/savetodb/configuring-translation.htm',NULL,11,NULL);
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, 'EventHandlers',NULL, 'Actions',NULL, 'Online Help', 'HTTP', 'http://www.savetodb.com/savetodb/configuring-event-handlers.htm',NULL,11,NULL);
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, 'ParameterValues',NULL, 'Actions',NULL, 'Online Help', 'HTTP', 'http://www.savetodb.com/savetodb/configuring-parameter-values.htm',NULL,11,NULL);
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, 'QueryList',NULL, 'Actions',NULL, 'Online Help', 'HTTP', 'http://www.savetodb.com/savetodb/configuring-query-list.htm',NULL,11,NULL);
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (NULL, 'TableFormats',NULL, 'Actions',NULL, 'Online Help', 'HTTP', 'http://www.savetodb.com/savetodb/configuring-table-formats.htm',NULL,11,NULL);

INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, 'QueryList', 'TABLE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,CODE,HTTP,TEXT');
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, 'QueryList', 'PROCEDURE_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,CODE,MERGE');
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, 'EventHandlers', 'EVENT_NAME', 'ValidationList', NULL, '', 'VALUES', 'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList');
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, 'EventHandlers', 'HANDLER_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR');
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, 'ParameterValues', 'SELECT_TYPE', 'ValidationList', NULL, '', 'VALUES', 'TABLE,VIEW,CODE,HTTP,VALUES,RANGE');
INSERT INTO [EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE]) VALUES (NULL, 'EventHandlers', 'HANDLER_CODE', 'DoNotConvertFormulas', NULL, '', NULL, NULL);

INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, 'ColumnTranslation', 'en', NULL, 'Configuration Table of Column Translation', 'The table defines translation for Excel table headers and ribbon fields');
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, 'EventHandlers', 'en', NULL, 'Configuration Table of Excel Event Handlers', 'The table defines Excel event handlers and Actions and Context Menu items');
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, 'ObjectTranslation', 'en', NULL, 'Configuration Table of Object Translation', 'The table defines translation for Query List, Actions and Context Menu items');
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, 'ParameterValues', 'en', NULL, 'Configuration Table of Parameter Value Queries', 'The table defines objects to select ribbon parameter values');
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, 'QueryList', 'en', NULL, 'Configuration Table of Query List', 'The table defines configuration of Query List objects');
INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, 'TableFormats', 'en', NULL, 'Configuration Table of Excel Table Formats', 'The table contains Excel formats of database objects');


INSERT INTO [ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC], [TRANSLATED_COMMENT]) VALUES (NULL, 'Online Help', 'en', 'Online Help', NULL, NULL);
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'QueryList', 'ID', 'en', NULL, NULL);
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'QueryList', 'TABLE_SCHEMA', 'en', NULL, 'Not used');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'QueryList', 'TABLE_NAME', 'en', NULL, 'Database object name or unique name for SQL-code and http-query');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'QueryList', 'TABLE_TYPE', 'en', NULL, 'Database object type, CODE for SQL-code, or HTTP for http-query');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'QueryList', 'TABLE_CODE', 'en', NULL, 'SQL-code or http-query');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'QueryList', 'INSERT_PROCEDURE', 'en', NULL, 'Destination table to save changes or INSERT SQL-code');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'QueryList', 'UPDATE_PROCEDURE', 'en', NULL, 'Destination table to save changes or UPDATE SQL-code');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'QueryList', 'DELETE_PROCEDURE', 'en', NULL, 'Destination table to save changes or DELETE SQL-code');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'ID', 'en', NULL, NULL);
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'TABLE_SCHEMA', 'en', NULL, 'Not used');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'TABLE_NAME', 'en', NULL, 'Database object name, SQL-code name, or http-query name');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'COLUMN_NAME', 'en', NULL, 'Column name or NULL to use the handler for entire table');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'EVENT_NAME', 'en', NULL, 'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'HANDLER_SCHEMA', 'en', NULL, 'Not used');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'HANDLER_NAME', 'en', NULL, 'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'HANDLER_TYPE', 'en', NULL, 'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'HANDLER_CODE', 'en', NULL, 'SQL-code or http-query');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'TARGET_WORKSHEET', 'en', NULL, 'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'MENU_ORDER', 'en', NULL, 'Sort order of Actions and Context Menu items');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'EventHandlers', 'EDIT_PARAMETERS', 'en', NULL, 'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ParameterValues', 'ID', 'en', NULL, NULL);
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ParameterValues', 'TABLE_SCHEMA', 'en', NULL, 'Not used');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ParameterValues', 'TABLE_NAME', 'en', NULL, 'Database object name');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ParameterValues', 'PARAMETER_NAME', 'en', NULL, 'Column name');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ParameterValues', 'SELECT_SCHEMA', 'en', NULL, 'Not used');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ParameterValues', 'SELECT_NAME', 'en', NULL, 'Database object name or name for SQL-code');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ParameterValues', 'SELECT_TYPE', 'en', NULL, 'Database object type or CODE for SQL-code');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ParameterValues', 'SELECT_CODE', 'en', NULL, 'SQL-code');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ObjectTranslation', 'ID', 'en', NULL, NULL);
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ObjectTranslation', 'TABLE_SCHEMA', 'en', NULL, 'Not used');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ObjectTranslation', 'TABLE_NAME', 'en', NULL, 'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ObjectTranslation', 'LANGUAGE_NAME', 'en', NULL, 'Two-char language code');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ObjectTranslation', 'TRANSLATED_NAME', 'en', NULL, 'Translated name for Query List, Actions and Context Menus');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ObjectTranslation', 'TRANSLATED_DESC', 'en', NULL, 'Text for ScreenTips and SaveToDB_Desc named cells');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ObjectTranslation', 'TRANSLATED_COMMENT', 'en', NULL, 'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ColumnTranslation', 'ID', 'en', NULL, NULL);
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ColumnTranslation', 'TABLE_SCHEMA', 'en', NULL, 'Not used');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ColumnTranslation', 'TABLE_NAME', 'en', NULL, 'Database object name or NULL for entire database scope');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ColumnTranslation', 'COLUMN_NAME', 'en', NULL, 'Column name');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ColumnTranslation', 'LANGUAGE_NAME', 'en', NULL, 'Two-char language code');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ColumnTranslation', 'TRANSLATED_NAME', 'en', NULL, 'Translated name for Excel table headers and ribbon parameters');
INSERT INTO [ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME], [TRANSLATED_DESC]) VALUES (NULL, 'ColumnTranslation', 'TRANSLATED_DESC', 'en', NULL, 'Text for Excel table header comments and ribbon parameter SuperTips');


INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, 'QueryList', '<?xml version="1.0" encoding="Unicode"?>
<table name=".QueryList">
<columnFormats>
<column name="" property="ListObjectName" value="QueryList_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="17.29" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_TYPE" property="Address" value="$F$7" type="String" />
<column name="TABLE_TYPE" property="ColumnWidth" value="13.14" type="Double" />
<column name="TABLE_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="TABLE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_TYPE" property="Validation.Formula1" value="TABLE;CODE;HTTP;TEXT" type="String" />
<column name="TABLE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_CODE" property="Address" value="$G$7" type="String" />
<column name="TABLE_CODE" property="ColumnWidth" value="70.71" type="Double" />
<column name="INSERT_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="INSERT_PROCEDURE" property="Address" value="$H$7" type="String" />
<column name="INSERT_PROCEDURE" property="ColumnWidth" value="20.71" type="Double" />
<column name="INSERT_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="UPDATE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="UPDATE_PROCEDURE" property="Address" value="$I$7" type="String" />
<column name="UPDATE_PROCEDURE" property="ColumnWidth" value="21.71" type="Double" />
<column name="UPDATE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="DELETE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DELETE_PROCEDURE" property="Address" value="$J$7" type="String" />
<column name="DELETE_PROCEDURE" property="ColumnWidth" value="20.71" type="Double" />
<column name="DELETE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="PROCEDURE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Address" value="$K$7" type="String" />
<column name="PROCEDURE_TYPE" property="ColumnWidth" value="18.86" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Formula1" value="TABLE;CODE;MERGE" type="String" />
<column name="PROCEDURE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="PROCEDURE_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="PROCEDURE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$9" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(2).AppliesTo.Address" value="$E$7:$E$9" type="String" />
<column name="TABLE_NAME" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(2).Priority" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$9" type="String" />
<column name="TABLE_TYPE" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="TABLE_TYPE" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_TYPE" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');

INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, 'EventHandlers', '<?xml version="1.0" encoding="Unicode"?>
<table name=".EventHandlers">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="17.29" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="17.43" type="Double" />
<column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EVENT_NAME" property="Address" value="$G$7" type="String" />
<column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double" />
<column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="EVENT_NAME" property="Validation.Type" value="3" type="Double" />
<column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String" />
<column name="EVENT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="EVENT_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" />
<column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String" />
<column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_NAME" property="Address" value="$I$7" type="String" />
<column name="HANDLER_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_TYPE" property="Address" value="$J$7" type="String" />
<column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double" />
<column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String" />
<column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="HANDLER_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(60) datatype." type="String" />
<column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_CODE" property="Address" value="$K$7" type="String" />
<column name="HANDLER_CODE" property="ColumnWidth" value="65.71" type="Double" />
<column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String" />
<column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double" />
<column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Formula1" value="255" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" />
<column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean" />
<column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="MENU_ORDER" property="Address" value="$M$7" type="String" />
<column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double" />
<column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double" />
<column name="MENU_ORDER" property="Validation.Type" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="MENU_ORDER" property="Validation.Formula2" value="2147483647" type="String" />
<column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String" />
<column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double" />
<column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$18" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$18" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$I$7:$I$18" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(I7)" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');

INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, 'ParameterValues', '<?xml version="1.0" encoding="Unicode"?>
<table name=".ParameterValues">
<columnFormats>
<column name="" property="ListObjectName" value="ParameterValues_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="17.29" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PARAMETER_NAME" property="Address" value="$F$7" type="String" />
<column name="PARAMETER_NAME" property="ColumnWidth" value="20.29" type="Double" />
<column name="PARAMETER_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="PARAMETER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="PARAMETER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Address" value="$G$7" type="String" />
<column name="SELECT_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="SELECT_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_NAME" property="Address" value="$H$7" type="String" />
<column name="SELECT_NAME" property="ColumnWidth" value="15.29" type="Double" />
<column name="SELECT_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SELECT_NAME" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="SELECT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_TYPE" property="Address" value="$I$7" type="String" />
<column name="SELECT_TYPE" property="ColumnWidth" value="13.86" type="Double" />
<column name="SELECT_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SELECT_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="SELECT_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_TYPE" property="Validation.Formula1" value="CODE;TABLE;VIEW;VALUES;RANGE" type="String" />
<column name="SELECT_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_CODE" property="Address" value="$J$7" type="String" />
<column name="SELECT_CODE" property="ColumnWidth" value="70.71" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$8" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$8" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(2).AppliesTo.Address" value="$F$7:$F$8" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(2).Priority" value="5" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(2).NumberFormat" value="General" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$H$7:$H$8" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(H7)" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(2).AppliesTo.Address" value="$H$7:$H$8" type="String" />
<column name="SELECT_NAME" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(2).Priority" value="6" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(H7)" type="String" />
<column name="SELECT_NAME" property="FormatConditions(2).NumberFormat" value="General" type="String" />
<column name="SELECT_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).AppliesTo.Address" value="$I$7:$I$8" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Formula1" value="=ISBLANK(I7)" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');

INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, 'ObjectTranslation', '<?xml version="1.0" encoding="Unicode"?>
<table name=".ObjectTranslation">
<columnFormats>
<column name="" property="ListObjectName" value="ObjectTranslation_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LANGUAGE_NAME" property="Address" value="$F$7" type="String" />
<column name="LANGUAGE_NAME" property="ColumnWidth" value="19.57" type="Double" />
<column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String" />
<column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="LANGUAGE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nchar(2) datatype." type="String" />
<column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_NAME" property="Address" value="$G$7" type="String" />
<column name="TRANSLATED_NAME" property="ColumnWidth" value="20.71" type="Double" />
<column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TRANSLATED_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_DESC" property="Address" value="$H$7" type="String" />
<column name="TRANSLATED_DESC" property="ColumnWidth" value="43.86" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Formula1" value="255" type="String" />
<column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TRANSLATED_DESC" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" />
<column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Address" value="$I$7" type="String" />
<column name="TRANSLATED_COMMENT" property="ColumnWidth" value="69.71" type="Double" />
<column name="TRANSLATED_COMMENT" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Formula1" value="4000" type="String" />
<column name="TRANSLATED_COMMENT" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TRANSLATED_COMMENT" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(4000) datatype." type="String" />
<column name="TRANSLATED_COMMENT" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$16" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$16" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).AppliesTo.Address" value="$F$7:$F$16" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Priority" value="3" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="LANGUAGE_NAME" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="TABLE_SCHEMA" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="TABLE_NAME" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');

INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, 'ColumnTranslation', '<?xml version="1.0" encoding="Unicode"?>
<table name=".ColumnTranslation">
<columnFormats>
<column name="" property="ListObjectName" value="ColumnTranslation_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="17.29" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="22.43" type="Double" />
<column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LANGUAGE_NAME" property="Address" value="$G$7" type="String" />
<column name="LANGUAGE_NAME" property="ColumnWidth" value="19.57" type="Double" />
<column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String" />
<column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="LANGUAGE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nchar(2) datatype." type="String" />
<column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_NAME" property="Address" value="$H$7" type="String" />
<column name="TRANSLATED_NAME" property="ColumnWidth" value="20.71" type="Double" />
<column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TRANSLATED_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String" />
<column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_DESC" property="Address" value="$I$7" type="String" />
<column name="TRANSLATED_DESC" property="ColumnWidth" value="70.71" type="Double" />
<column name="TRANSLATED_DESC" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Formula1" value="1024" type="String" />
<column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ErrorTitle" value="Datatype Control" type="String" />
<column name="TRANSLATED_DESC" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(1024) datatype." type="String" />
<column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$55" type="String" />
<column name="COLUMN_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="COLUMN_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="COLUMN_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="COLUMN_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="COLUMN_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$55" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).AppliesTo.Address" value="$G$7:$G$55" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Priority" value="3" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Interior.Color" value="65535" type="Double" />
<column name="LANGUAGE_NAME" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
');

INSERT INTO [TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (NULL, 'TableFormats', '<?xml version="1.0" encoding="Unicode"?>
<table name="TableFormats">
<columnFormats>
<column name="" property="ListObjectName" value="UserObjects_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="_RowNum" property="WrapText" value="True" type="Boolean" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="WrapText" value="True" type="Boolean" />
<column name="ID" property="Validation.Type" value="1" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="1" type="Double" />
<column name="ID" property="Validation.Formula1" value="-2147483648" type="String" />
<column name="ID" property="Validation.Formula2" value="2147483647" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="WrapText" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="17.29" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="WrapText" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_EXCEL_FORMAT_XML" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_EXCEL_FORMAT_XML" property="Address" value="$F$7" type="String" />
<column name="TABLE_EXCEL_FORMAT_XML" property="ColumnWidth" value="101.86" type="Double" />
<column name="TABLE_EXCEL_FORMAT_XML" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$11" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.Zoom" value="100" type="Double" />
</columnFormats>
</table>');

-- print SaveToDB Framework data have been added

-- print SaveToDB Framework has been installed
