-- =============================================
-- SaveToDB Framework for SQLite
-- Version 8.15, November 7, 2018
--
-- This script upgrades SaveToDB Framework 8.11 to SaveToDB Framework 8.15
--
-- Copyright 2017-2018 Gartle Technology Corporation
-- =============================================

UPDATE handlers SET HANDLER_CODE = 'TABLE, VIEW, CODE, HTTP, TEXT, MACRO, CMD, VALUES, RANGE, REFRESH, MENUSEPARATOR, PDF, REPORT, SHOWSHEETS, HIDESHEETS, SELECTSHEET'
    WHERE TABLE_SCHEMA IS NULL AND TABLE_NAME = 'handlers' AND COLUMN_NAME = 'HANDLER_TYPE' AND EVENT_NAME = 'ValidationList' AND HANDLER_TYPE = 'VALUES';

DROP VIEW queries;

CREATE VIEW queries
AS
SELECT
    NULL AS TABLE_SCHEMA
    , t.name AS TABLE_NAME
    , t.type AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    sqlite_master t
    LEFT OUTER JOIN objects o ON o.TABLE_NAME = t.name
WHERE
    t.type IN ('table', 'view')
    AND t.name NOT IN ('sqlite_master', 'sqlite_sequence', 
        'objects', 'handlers', 'translations', 'formats', 'queries',
        'ColumnTranslation', 'ObjectTranslation', 'EventHandlers', 'ParameterValues', 'TableFormats', 'QueryList',
        'viewColumnTranslation', 'viewObjectTranslation', 'viewEventHandlers', 'viewParameterValues', 'viewTableFormats', 'viewQueryList')
    AND NOT t.name LIKE 'sqlite_stat%'
    AND NOT t.name LIKE 'xl_%'
    AND NOT COALESCE(UPPER(o.TABLE_TYPE), '') = 'HIDDEN'
UNION ALL
SELECT
    o.TABLE_SCHEMA
    , o.TABLE_NAME
    , o.TABLE_TYPE
    , o.TABLE_CODE
    , o.INSERT_OBJECT AS INSERT_PROCEDURE
    , o.UPDATE_OBJECT AS UPDATE_PROCEDURE
    , o.DELETE_OBJECT AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    objects o
WHERE
    o.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND o.TABLE_NAME IS NOT NULL
    AND o.TABLE_CODE IS NOT NULL
    AND NOT o.TABLE_NAME LIKE 'xl_%'
;
